/*
 * r8a7779 processor support - PFC hardware block
 *
 * Copyright (C) 2011  Renesas Solutions Corp.
 * Copyright (C) 2011  Magnus Damm
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include <linux/init.h>
#include <linux/kernel.h>
#include <linux/sh_pfc.h>
#include <linux/ioport.h>
#include <mach/r8a7779.h>

#define CPU_32_PORT(fn, pfx, sfx)				\
	PORT_10(fn, pfx, sfx), PORT_10(fn, pfx##1, sfx),	\
	PORT_10(fn, pfx##2, sfx), PORT_1(fn, pfx##30, sfx),	\
	PORT_1(fn, pfx##31, sfx)

#define CPU_32_PORT6(fn, pfx, sfx)				\
	PORT_1(fn, pfx##0, sfx), PORT_1(fn, pfx##1, sfx),	\
	PORT_1(fn, pfx##2, sfx), PORT_1(fn, pfx##3, sfx),	\
	PORT_1(fn, pfx##4, sfx), PORT_1(fn, pfx##5, sfx),	\
	PORT_1(fn, pfx##6, sfx), PORT_1(fn, pfx##7, sfx),	\
	PORT_1(fn, pfx##8, sfx)

#define CPU_ALL_PORT(fn, pfx, sfx)				\
	CPU_32_PORT(fn, pfx##_0_, sfx),				\
	CPU_32_PORT(fn, pfx##_1_, sfx),				\
	CPU_32_PORT(fn, pfx##_2_, sfx),				\
	CPU_32_PORT(fn, pfx##_3_, sfx),				\
	CPU_32_PORT(fn, pfx##_4_, sfx),				\
	CPU_32_PORT(fn, pfx##_5_, sfx),				\
	CPU_32_PORT6(fn, pfx##_6_, sfx)

#define _GP_GPIO(pfx, sfx) PINMUX_GPIO(GPIO_GP##pfx, GP##pfx##_DATA)
#define _GP_DATA(pfx, sfx) PINMUX_DATA(GP##pfx##_DATA, GP##pfx##_FN,	\
				       GP##pfx##_IN, GP##pfx##_OUT)

#define _GP_INOUTSEL(pfx, sfx) GP##pfx##_IN, GP##pfx##_OUT
#define _GP_INDT(pfx, sfx) GP##pfx##_DATA

#define GP_ALL(str)	CPU_ALL_PORT(_PORT_ALL, GP, str)
#define PINMUX_GPIO_GP_ALL()	CPU_ALL_PORT(_GP_GPIO, , unused)
#define PINMUX_DATA_GP_ALL()	CPU_ALL_PORT(_GP_DATA, , unused)


#define PORT_10_REV(fn, pfx, sfx)				\
	PORT_1(fn, pfx##9, sfx), PORT_1(fn, pfx##8, sfx),	\
	PORT_1(fn, pfx##7, sfx), PORT_1(fn, pfx##6, sfx),	\
	PORT_1(fn, pfx##5, sfx), PORT_1(fn, pfx##4, sfx),	\
	PORT_1(fn, pfx##3, sfx), PORT_1(fn, pfx##2, sfx),	\
	PORT_1(fn, pfx##1, sfx), PORT_1(fn, pfx##0, sfx)

#define CPU_32_PORT_REV(fn, pfx, sfx)					\
	PORT_1(fn, pfx##31, sfx), PORT_1(fn, pfx##30, sfx),		\
	PORT_10_REV(fn, pfx##2, sfx), PORT_10_REV(fn, pfx##1, sfx),	\
	PORT_10_REV(fn, pfx, sfx)

#define GP_INOUTSEL(bank) CPU_32_PORT_REV(_GP_INOUTSEL, _##bank##_, unused)
#define GP_INDT(bank) CPU_32_PORT_REV(_GP_INDT, _##bank##_, unused)

#define PINMUX_IPSR_DATA(ipsr, fn) PINMUX_DATA(fn##_MARK, FN_##ipsr, FN_##fn)
#define PINMUX_IPSR_MODSEL_DATA(ipsr, fn, ms) PINMUX_DATA(fn##_MARK, FN_##ms, \
							  FN_##ipsr, FN_##fn)

enum {
	PINMUX_RESERVED = 0,

	PINMUX_DATA_BEGIN,
	GP_ALL(DATA), /* GP_0_0_DATA -> GP_6_8_DATA */
	PINMUX_DATA_END,

	PINMUX_INPUT_BEGIN,
	GP_ALL(IN), /* GP_0_0_IN -> GP_6_8_IN */
	PINMUX_INPUT_END,

	PINMUX_OUTPUT_BEGIN,
	GP_ALL(OUT), /* GP_0_0_OUT -> GP_6_8_OUT */
	PINMUX_OUTPUT_END,

	PINMUX_FUNCTION_BEGIN,
	GP_ALL(FN), /* GP_0_0_FN -> GP_6_8_FN */

	/* GPSR0 */
	FN_AVS1, FN_AVS2, FN_IP0_7_6, FN_A17,
	FN_A18, FN_A19, FN_IP0_9_8, FN_IP0_11_10,
	FN_IP0_13_12, FN_IP0_15_14, FN_IP0_18_16, FN_IP0_22_19,
	FN_IP0_24_23, FN_IP0_25, FN_IP0_27_26, FN_IP1_1_0,
	FN_IP1_3_2, FN_IP1_6_4, FN_IP1_10_7, FN_IP1_14_11,
	FN_IP1_18_15, FN_IP0_5_3, FN_IP0_30_28, FN_IP2_18_16,
	FN_IP2_21_19, FN_IP2_30_28, FN_IP3_2_0, FN_IP3_11_9,
	FN_IP3_14_12, FN_IP3_22_21, FN_IP3_26_24, FN_IP3_31_29,

	/* GPSR1 */
	FN_IP4_1_0, FN_IP4_4_2, FN_IP4_7_5, FN_IP4_10_8,
	FN_IP4_11, FN_IP4_12, FN_IP4_13, FN_IP4_14,
	FN_IP4_15, FN_IP4_16, FN_IP4_19_17, FN_IP4_22_20,
	FN_IP4_23, FN_IP4_24, FN_IP4_25, FN_IP4_26,
	FN_IP4_27, FN_IP4_28, FN_IP4_31_29, FN_IP5_2_0,
	FN_IP5_3, FN_IP5_4, FN_IP5_5, FN_IP5_6,
	FN_IP5_7, FN_IP5_8, FN_IP5_10_9, FN_IP5_12_11,
	FN_IP5_14_13, FN_IP5_16_15, FN_IP5_20_17, FN_IP5_23_21,

	/* GPSR2 */
	FN_IP5_27_24, FN_IP8_20, FN_IP8_22_21, FN_IP8_24_23,
	FN_IP8_27_25, FN_IP8_30_28, FN_IP9_1_0, FN_IP9_3_2,
	FN_IP9_4, FN_IP9_5, FN_IP9_6, FN_IP9_7,
	FN_IP9_9_8, FN_IP9_11_10, FN_IP9_13_12, FN_IP9_15_14,
	FN_IP9_18_16, FN_IP9_21_19, FN_IP9_23_22, FN_IP9_25_24,
	FN_IP9_27_26, FN_IP9_29_28, FN_IP10_2_0, FN_IP10_5_3,
	FN_IP10_8_6, FN_IP10_11_9, FN_IP10_14_12, FN_IP10_17_15,
	FN_IP10_20_18, FN_IP10_23_21, FN_IP10_25_24, FN_IP10_28_26,

	/* GPSR3 */
	FN_IP10_31_29, FN_IP11_2_0, FN_IP11_5_3, FN_IP11_8_6,
	FN_IP11_11_9, FN_IP11_14_12, FN_IP11_17_15, FN_IP11_20_18,
	FN_IP11_23_21, FN_IP11_26_24, FN_IP11_29_27, FN_IP12_2_0,
	FN_IP12_5_3, FN_IP12_8_6, FN_IP12_11_9, FN_IP12_14_12,
	FN_IP12_17_15, FN_IP7_16_15, FN_IP7_18_17, FN_IP7_28_27,
	FN_IP7_30_29, FN_IP7_20_19, FN_IP7_22_21, FN_IP7_24_23,
	FN_IP7_26_25, FN_IP1_20_19, FN_IP1_22_21, FN_IP1_24_23,
	FN_IP5_28, FN_IP5_30_29, FN_IP6_1_0, FN_IP6_3_2,

	/* GPSR4 */
	FN_IP6_5_4, FN_IP6_7_6, FN_IP6_8, FN_IP6_11_9,
	FN_IP6_14_12, FN_IP6_17_15, FN_IP6_19_18, FN_IP6_22_20,
	FN_IP6_24_23, FN_IP6_26_25, FN_IP6_30_29, FN_IP7_1_0,
	FN_IP7_3_2, FN_IP7_6_4, FN_IP7_9_7, FN_IP7_12_10,
	FN_IP7_14_13, FN_IP2_7_4, FN_IP2_11_8, FN_IP2_15_12,
	FN_IP1_28_25, FN_IP2_3_0, FN_IP8_3_0, FN_IP8_7_4,
	FN_IP8_11_8, FN_IP8_15_12, FN_USB_PENC0, FN_USB_PENC1,
	FN_IP0_2_0, FN_IP8_17_16, FN_IP8_18, FN_IP8_19,

	/* GPSR5 */
	FN_A1, FN_A2, FN_A3, FN_A4,
	FN_A5, FN_A6, FN_A7, FN_A8,
	FN_A9, FN_A10, FN_A11, FN_A12,
	FN_A13, FN_A14, FN_A15, FN_A16,
	FN_RD, FN_WE0, FN_WE1, FN_EX_WAIT0,
	FN_IP3_23, FN_IP3_27, FN_IP3_28, FN_IP2_22,
	FN_IP2_23, FN_IP2_24, FN_IP2_25, FN_IP2_26,
	FN_IP2_27, FN_IP3_3, FN_IP3_4, FN_IP3_5,

	/* GPSR6 */
	FN_IP3_6, FN_IP3_7, FN_IP3_8, FN_IP3_15,
	FN_IP3_16, FN_IP3_17, FN_IP3_18, FN_IP3_19,
	FN_IP3_20,

	/* IPSR0 */
	FN_RD_WR, FN_FWE, FN_ATAG0, FN_VI1_R7,
	FN_HRTS1, FN_RX4_C,
	FN_CS1_A26, FN_HSPI_TX2, FN_SDSELF_B,
	FN_CS0, FN_HSPI_CS2_B,
	FN_CLKOUT, FN_TX3C_IRDA_TX_C, FN_PWM0_B,
	FN_A25, FN_SD1_WP, FN_MMC0_D5, FN_FD5,
	FN_HSPI_RX2, FN_VI1_R3, FN_TX5_B, FN_SSI_SDATA7_B,
	FN_CTS0_B,
	FN_A24, FN_SD1_CD, FN_MMC0_D4, FN_FD4,
	FN_HSPI_CS2, FN_VI1_R2, FN_SSI_WS78_B,
	FN_A23, FN_FCLE, FN_HSPI_CLK2, FN_VI1_R1,
	FN_A22, FN_RX5_D, FN_HSPI_RX2_B, FN_VI1_R0,
	FN_A21, FN_SCK5_D, FN_HSPI_CLK2_B,
	FN_A20, FN_TX5_D, FN_HSPI_TX2_B,
	FN_A0, FN_SD1_DAT3, FN_MMC0_D3, FN_FD3,
	FN_BS, FN_SD1_DAT2, FN_MMC0_D2, FN_FD2,
	FN_ATADIR0, FN_SDSELF, FN_HCTS1, FN_TX4_C,
	FN_USB_PENC2, FN_SCK0, FN_PWM1, FN_PWMFSW0,
	FN_SCIF_CLK, FN_TCLK0_C,

	/* IPSR1 */
	FN_EX_CS0, FN_RX3_C_IRDA_RX_C, FN_MMC0_D6,
	FN_FD6, FN_EX_CS1, FN_MMC0_D7, FN_FD7,
	FN_EX_CS2, FN_SD1_CLK, FN_MMC0_CLK, FN_FALE,
	FN_ATACS00, FN_EX_CS3, FN_SD1_CMD, FN_MMC0_CMD,
	FN_FRE, FN_ATACS10, FN_VI1_R4, FN_RX5_B,
	FN_HSCK1, FN_SSI_SDATA8_B, FN_RTS0_B_TANS_B, FN_SSI_SDATA9,
	FN_EX_CS4, FN_SD1_DAT0, FN_MMC0_D0, FN_FD0,
	FN_ATARD0, FN_VI1_R5, FN_SCK5_B, FN_HTX1,
	FN_TX2_E, FN_TX0_B, FN_SSI_SCK9, FN_EX_CS5,
	FN_SD1_DAT1, FN_MMC0_D1, FN_FD1, FN_ATAWR0,
	FN_VI1_R6, FN_HRX1, FN_RX2_E, FN_RX0_B,
	FN_SSI_WS9, FN_MLB_CLK, FN_PWM2, FN_SCK4,
	FN_MLB_SIG, FN_PWM3, FN_TX4, FN_MLB_DAT,
	FN_PWM4, FN_RX4, FN_HTX0, FN_TX1,
	FN_SDATA, FN_CTS0_C, FN_SUB_TCK, FN_CC5_STATE2,
	FN_CC5_STATE10, FN_CC5_STATE18, FN_CC5_STATE26, FN_CC5_STATE34,

	/* IPSR2 */
	FN_HRX0, FN_RX1, FN_SCKZ, FN_RTS0_C_TANS_C,
	FN_SUB_TDI, FN_CC5_STATE3, FN_CC5_STATE11, FN_CC5_STATE19,
	FN_CC5_STATE27, FN_CC5_STATE35, FN_HSCK0, FN_SCK1,
	FN_MTS, FN_PWM5, FN_SCK0_C, FN_SSI_SDATA9_B,
	FN_SUB_TDO, FN_CC5_STATE0, FN_CC5_STATE8, FN_CC5_STATE16,
	FN_CC5_STATE24, FN_CC5_STATE32, FN_HCTS0, FN_CTS1,
	FN_STM, FN_PWM0_D, FN_RX0_C, FN_SCIF_CLK_C,
	FN_SUB_TRST, FN_TCLK1_B, FN_CC5_OSCOUT, FN_HRTS0,
	FN_RTS1_TANS, FN_MDATA, FN_TX0_C, FN_SUB_TMS,
	FN_CC5_STATE1, FN_CC5_STATE9, FN_CC5_STATE17, FN_CC5_STATE25,
	FN_CC5_STATE33, FN_DU0_DR0, FN_LCDOUT0, FN_DREQ0,
	FN_GPS_CLK_B, FN_AUDATA0, FN_TX5_C, FN_DU0_DR1,
	FN_LCDOUT1, FN_DACK0, FN_DRACK0, FN_GPS_SIGN_B,
	FN_AUDATA1, FN_RX5_C, FN_DU0_DR2, FN_LCDOUT2,
	FN_DU0_DR3, FN_LCDOUT3, FN_DU0_DR4, FN_LCDOUT4,
	FN_DU0_DR5, FN_LCDOUT5, FN_DU0_DR6, FN_LCDOUT6,
	FN_DU0_DR7, FN_LCDOUT7, FN_DU0_DG0, FN_LCDOUT8,
	FN_DREQ1, FN_SCL2, FN_AUDATA2,

	/* IPSR3 */
	FN_DU0_DG1, FN_LCDOUT9, FN_DACK1, FN_SDA2,
	FN_AUDATA3, FN_DU0_DG2, FN_LCDOUT10, FN_DU0_DG3,
	FN_LCDOUT11, FN_DU0_DG4, FN_LCDOUT12, FN_DU0_DG5,
	FN_LCDOUT13, FN_DU0_DG6, FN_LCDOUT14, FN_DU0_DG7,
	FN_LCDOUT15, FN_DU0_DB0, FN_LCDOUT16, FN_EX_WAIT1,
	FN_SCL1, FN_TCLK1, FN_AUDATA4, FN_DU0_DB1,
	FN_LCDOUT17, FN_EX_WAIT2, FN_SDA1, FN_GPS_MAG_B,
	FN_AUDATA5, FN_SCK5_C, FN_DU0_DB2, FN_LCDOUT18,
	FN_DU0_DB3, FN_LCDOUT19, FN_DU0_DB4, FN_LCDOUT20,
	FN_DU0_DB5, FN_LCDOUT21, FN_DU0_DB6, FN_LCDOUT22,
	FN_DU0_DB7, FN_LCDOUT23, FN_DU0_DOTCLKIN, FN_QSTVA_QVS,
	FN_TX3_D_IRDA_TX_D, FN_SCL3_B, FN_DU0_DOTCLKOUT0, FN_QCLK,
	FN_DU0_DOTCLKOUT1, FN_QSTVB_QVE, FN_RX3_D_IRDA_RX_D, FN_SDA3_B,
	FN_SDA2_C, FN_DACK0_B, FN_DRACK0_B, FN_DU0_EXHSYNC_DU0_HSYNC,
	FN_QSTH_QHS, FN_DU0_EXVSYNC_DU0_VSYNC, FN_QSTB_QHE,
	FN_DU0_EXODDF_DU0_ODDF_DISP_CDE, FN_QCPV_QDE, FN_CAN1_TX,
	FN_TX2_C, FN_SCL2_C, FN_REMOCON,

	/* IPSR4 */
	FN_DU0_DISP, FN_QPOLA, FN_CAN_CLK_C, FN_SCK2_C,
	FN_DU0_CDE, FN_QPOLB, FN_CAN1_RX, FN_RX2_C,
	FN_DREQ0_B, FN_SSI_SCK78_B, FN_SCK0_B, FN_DU1_DR0,
	FN_VI2_DATA0_VI2_B0, FN_PWM6, FN_SD3_CLK, FN_TX3_E_IRDA_TX_E,
	FN_AUDCK, FN_PWMFSW0_B, FN_DU1_DR1, FN_VI2_DATA1_VI2_B1,
	FN_PWM0, FN_SD3_CMD, FN_RX3_E_IRDA_RX_E, FN_AUDSYNC,
	FN_CTS0_D, FN_DU1_DR2, FN_VI2_G0, FN_DU1_DR3,
	FN_VI2_G1, FN_DU1_DR4, FN_VI2_G2, FN_DU1_DR5,
	FN_VI2_G3, FN_DU1_DR6, FN_VI2_G4, FN_DU1_DR7,
	FN_VI2_G5, FN_DU1_DG0, FN_VI2_DATA2_VI2_B2, FN_SCL1_B,
	FN_SD3_DAT2, FN_SCK3_E, FN_AUDATA6, FN_TX0_D,
	FN_DU1_DG1, FN_VI2_DATA3_VI2_B3, FN_SDA1_B, FN_SD3_DAT3,
	FN_SCK5, FN_AUDATA7, FN_RX0_D, FN_DU1_DG2,
	FN_VI2_G6, FN_DU1_DG3, FN_VI2_G7, FN_DU1_DG4,
	FN_VI2_R0, FN_DU1_DG5, FN_VI2_R1, FN_DU1_DG6,
	FN_VI2_R2, FN_DU1_DG7, FN_VI2_R3, FN_DU1_DB0,
	FN_VI2_DATA4_VI2_B4, FN_SCL2_B, FN_SD3_DAT0, FN_TX5,
	FN_SCK0_D,

	/* IPSR5 */
	FN_DU1_DB1, FN_VI2_DATA5_VI2_B5, FN_SDA2_B, FN_SD3_DAT1,
	FN_RX5, FN_RTS0_D_TANS_D, FN_DU1_DB2, FN_VI2_R4,
	FN_DU1_DB3, FN_VI2_R5, FN_DU1_DB4, FN_VI2_R6,
	FN_DU1_DB5, FN_VI2_R7, FN_DU1_DB6, FN_SCL2_D,
	FN_DU1_DB7, FN_SDA2_D, FN_DU1_DOTCLKIN, FN_VI2_CLKENB,
	FN_HSPI_CS1, FN_SCL1_D, FN_DU1_DOTCLKOUT, FN_VI2_FIELD,
	FN_SDA1_D, FN_DU1_EXHSYNC_DU1_HSYNC, FN_VI2_HSYNC,
	FN_VI3_HSYNC, FN_DU1_EXVSYNC_DU1_VSYNC, FN_VI2_VSYNC, FN_VI3_VSYNC,
